@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// Vramsteg - Utility for displaying progress bars in shell scripts.
 //
-// Copyright 2010 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2010 - 2017, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,121 +24,24 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
+#include <Progress.h>
 #include <iostream>
 #include <sstream>
 #include <iomanip>
-#include <stdio.h>
+#include <cstdio>
 #include <unistd.h>
-#include <Progress.h>
-
-////////////////////////////////////////////////////////////////////////////////
-Progress::Progress ()
-: style ("")
-, label ("")
-, width (0)
-, minimum (0)
-, maximum (0)
-, current (-1)
-, percentage (true)
-, remove (true)
-, start (0)
-, estimate (false)
-, elapsed (false)
-{
-}
-
-////////////////////////////////////////////////////////////////////////////////
-Progress::Progress (const std::string& l, int w, long n, long x, bool p /* = true */, bool r /* = true */)
-: style ("")
-, label (l)
-, width (w)
-, minimum (n)
-, maximum (x)
-, percentage (p)
-, remove (r)
-, start (0)
-, estimate (false)
-, elapsed (false)
-{
-  current = -1;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-Progress::~Progress ()
-{
-}
-
-////////////////////////////////////////////////////////////////////////////////
-void Progress::setStyle (const std::string& value)
-{
-  style = value;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-void Progress::setLabel (const std::string& value)
-{
-  label = value;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-void Progress::setWidth (int value)
-{
-  width = value;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-void Progress::setMin (long value)
-{
-  minimum = value;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-void Progress::setMax (long value)
-{
-  maximum = value;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-void Progress::showPercentage (bool value)
-{
-  percentage = value;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-void Progress::removeAfter (bool value)
-{
-  remove = value;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-void Progress::setStart (time_t value)
-{
-  start = value;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-void Progress::showEstimate (bool value)
-{
-  estimate = value;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-void Progress::showElapsed (bool value)
-{
-  elapsed = value;
-}
 
 ////////////////////////////////////////////////////////////////////////////////
 void Progress::update (long value)
 {
-  if (isatty (fileno (stdout)) && current != value)
+  if (isatty (fileno (stdout)) && _current != value)
   {
     // Box the range.
     if (value < minimum) value = minimum;
     if (value > maximum) value = maximum;
 
     // Current value.
-    current = value;
+    _current = value;
 
     // Capable of supporting multiple styles.
          if (style == "")     renderStyleDefault ();
@@ -151,7 +53,7 @@ void Progress::update (long value)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-void Progress::done ()
+void Progress::done () const
 {
   if (isatty (fileno (stdout)))
   {
@@ -166,7 +68,7 @@ void Progress::done ()
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-std::string Progress::formatTime (time_t t)
+std::string Progress::formatTime (time_t t) const
 {
   char buffer [128];
 
@@ -196,13 +98,13 @@ std::string Progress::formatTime (time_t t)
 //                                 ^^^^             Percentage complete
 //                                      ^^^^        Elapsed time
 //                                           ^^^^   Remaining estimate
-void Progress::renderStyleDefault ()
+void Progress::renderStyleDefault () const
 {
   // Fraction completed.
-  double fraction = (1.0 * (current - minimum)) / (maximum - minimum);
+  double fraction = (1.0 * (_current - minimum)) / (maximum - minimum);
 
   // Elapsed time.
-  time_t now = time (NULL);
+  auto now = time (nullptr);
   std::string elapsed_time;
   if (elapsed && start != 0)
     elapsed_time = formatTime (now - start);
@@ -218,11 +120,11 @@ void Progress::renderStyleDefault ()
   }
 
   // Calculate bar width.
-  int bar = width
-          - (label.length () ? label.length () + 1         : 0)
-          - (percentage      ? 5                           : 0)
-          - (elapsed         ? elapsed_time.length () + 1  : 0)
-          - (estimate        ? estimate_time.length () + 1 : 0);
+  auto bar = width
+           - (label.length () ? label.length () + 1         : 0)
+           - (percentage      ? 5                           : 0)
+           - (elapsed         ? elapsed_time.length () + 1  : 0)
+           - (estimate        ? estimate_time.length () + 1 : 0);
 
   if (bar < 1)
     throw std::string ("The specified width is insufficient.");
@@ -278,13 +180,13 @@ void Progress::renderStyleDefault ()
 //                                 ^^^^             Percentage complete
 //                                      ^^^^        Elapsed time
 //                                           ^^^^   Remaining estimate
-void Progress::renderStyleMono ()
+void Progress::renderStyleMono () const
 {
   // Fraction completed.
-  double fraction = (1.0 * (current - minimum)) / (maximum - minimum);
+  double fraction = (1.0 * (_current - minimum)) / (maximum - minimum);
 
   // Elapsed time.
-  time_t now = time (NULL);
+  auto now = time (nullptr);
   std::string elapsed_time;
   if (elapsed && start != 0)
     elapsed_time = formatTime (now - start);
@@ -300,11 +202,11 @@ void Progress::renderStyleMono ()
   }
 
   // Calculate bar width.
-  int bar = width
-          - (label.length () ? label.length () + 1         : 0)
-          - (percentage      ? 5                           : 0)
-          - (elapsed         ? elapsed_time.length () + 1  : 0)
-          - (estimate        ? estimate_time.length () + 1 : 0);
+  auto bar = width
+           - (label.length () ? label.length () + 1         : 0)
+           - (percentage      ? 5                           : 0)
+           - (elapsed         ? elapsed_time.length () + 1  : 0)
+           - (estimate        ? estimate_time.length () + 1 : 0);
 
   if (bar < 1)
     throw std::string ("The specified width is insufficient.");
@@ -360,13 +262,13 @@ void Progress::renderStyleMono ()
 //                                  ^^^^             Percentage complete
 //                                       ^^^^        Elapsed time
 //                                            ^^^^   Remaining estimate
-void Progress::renderStyleText ()
+void Progress::renderStyleText () const
 {
   // Fraction completed.
-  double fraction = (1.0 * (current - minimum)) / (maximum - minimum);
+  double fraction = (1.0 * (_current - minimum)) / (maximum - minimum);
 
   // Elapsed time.
-  time_t now = time (NULL);
+  auto now = time (nullptr);
   std::string elapsed_time;
   if (elapsed && start != 0)
     elapsed_time = formatTime (now - start);
@@ -382,12 +284,12 @@ void Progress::renderStyleText ()
   }
 
   // Calculate bar width.
-  int bar = width
-          - 2                                                    // The [ and ]
-          - (label.length () ? label.length () + 1         : 0)
-          - (percentage      ? 5                           : 0)
-          - (elapsed         ? elapsed_time.length () + 1  : 0)
-          - (estimate        ? estimate_time.length () + 1 : 0);
+  auto bar = width
+           - 2                                                    // The [ and ]
+           - (label.length () ? label.length () + 1         : 0)
+           - (percentage      ? 5                           : 0)
+           - (elapsed         ? elapsed_time.length () + 1  : 0)
+           - (estimate        ? estimate_time.length () + 1 : 0);
 
   if (bar < 1)
     throw std::string ("The specified width is insufficient.");
