@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// Vramsteg - Utility for displaying progress bars in shell scripts.
 //
-// Copyright 2010 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2010 - 2017, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -29,48 +28,34 @@
 #define INCLUDED_PROGRESS
 
 #include <string>
-#include <time.h>
+#include <ctime>
 
 class Progress
 {
 public:
-  Progress ();
-  Progress (const std::string&, int, long, long, bool = true, bool = true);
-  ~Progress ();
-
-  void setStyle (const std::string&);
-  void setLabel (const std::string&);
-  void setWidth (int);
-  void setMin (long);
-  void setMax (long);
-  void showPercentage (bool);
-  void removeAfter (bool);
-  void setStart (time_t);
-  void showEstimate (bool);
-  void showElapsed (bool);
-
   void update (long);
-  void done ();
+  void done () const;
 
 private:
-  std::string formatTime (time_t);
+  std::string formatTime (time_t) const;
+  void renderStyleDefault () const;
+  void renderStyleMono () const;
+  void renderStyleText () const;
 
-  void renderStyleDefault ();
-  void renderStyleMono ();
-  void renderStyleText ();
+public:
+  std::string style {};
+  std::string label {};
+  int width         {80};
+  long minimum      {0};
+  long maximum      {0};
+  bool percentage   {true};
+  bool remove       {true};
+  time_t start      {0};
+  bool estimate     {false};
+  bool elapsed      {false};
 
 private:
-  std::string style;
-  std::string label;
-  int width;
-  long minimum;
-  long maximum;
-  long current;
-  bool percentage;
-  bool remove;
-  time_t start;
-  bool estimate;
-  bool elapsed;
+  long _current     {-1};
 };
 
 #endif
