@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// Vramsteg - Utility for displaying progress bars in shell scripts.
 //
-// Copyright 2010 - 2015, Paul Beckingham, Federico Hernandez.
+// Copyright 2010 - 2017, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,12 +26,12 @@
 
 #include <iostream>
 #include <sys/ioctl.h>
-#include <stdio.h>
-#include <stdlib.h>
+#include <cstdio>
+#include <cstdlib>
 #include <getopt.h>
 #include <unistd.h>
-#include <time.h>
-#include <signal.h>
+#include <ctime>
+#include <csignal>
 #include <Progress.h>
 #include <cmake.h>
 
@@ -60,10 +59,6 @@ void showUsage ()
             << "  -r, --remove                Removes the progress bar\n"
             << "  -e, --elapsed               Show elapsed time (needs --start)\n"
             << "  -t, --estimate              Show estimated remaining time (needs --start)\n"
-#ifdef WAITING_FOR_VITAPI
-            << "  -d, --done <color>          Color of completed part\n"
-            << "  -a, --remaining <color>     Color of incomplete part\n"
-#endif
             << "  -v, --version               Show vramsteg version\n"
             << "  -h, --help                  Show command options\n"
             << "\n"
@@ -71,7 +66,7 @@ void showUsage ()
             << "  (default)     label \033[42m        \033[41m            \033[0m 40%\n"
             << "  mono          label \033[47m    \033[40m                \033[0m 20%\n"
             << "  text          label [************      ] 60%\n"
-            << std::endl;
+            << "\n";
 
   exit (0);
 }
@@ -81,15 +76,15 @@ void showVersion ()
 {
   std::cout << "\n"
             << "\033[1m" << PACKAGE_STRING << "\033[0m\n"
-            << "Copyright (C) 2010 - 2015, Göteborg Bit Factory\n"
-            << "Copyright (C) 2010 - 2015, P. Beckingham, F. Hernandez.\n"
+            << "Copyright (C) 2010 - 2017, Gothenburg Bit Factory\n"
+            << "Copyright (C) 2010 - 2017, P. Beckingham, F. Hernandez.\n"
             << "\n"
             << "Vramsteg may be copied only under the terms of the MIT license, "
             << "which may be found in the taskwarrior source kit.\n"
             << "\n"
             << "Documentation for vramsteg can be found using 'man vramsteg', or "
-            << "at http://tasktools.org.\n\n"
-            << std::flush;
+            << "at https://gotenburgbitfactory.org/vramsteg.\n"
+            << "\n";
 
   exit (0);
 }
@@ -103,29 +98,22 @@ int main (int argc, char** argv)
     // this would lead to odd colors persisting in the terminal.
     signal (SIGHUP,    SIG_IGN);
     signal (SIGINT,    SIG_IGN);
-    signal (SIGKILL,   SIG_IGN);
     signal (SIGPIPE,   SIG_IGN);
     signal (SIGTERM,   SIG_IGN);
     signal (SIGUSR1,   SIG_IGN);
     signal (SIGUSR2,   SIG_IGN);
 
-    long        arg_current    = 0;
-#ifdef WAITING_FOR_VITAPI
-    std::string arg_done       = "";
-#endif
-    bool        arg_elapsed    = false;
-    bool        arg_estimate   = false;
-    std::string arg_label;
-    long        arg_max        = 0;
-    long        arg_min        = 0;
-    bool        arg_percentage = false;
-#ifdef WAITING_FOR_VITAPI
-    std::string arg_remaining  = "";
-#endif
-    bool        arg_remove     = false;
-    time_t      arg_start      = 0;
-    int         arg_width      = 80;
-    std::string arg_style      = "";
+    long        arg_current    {0};
+    bool        arg_elapsed    {false};
+    bool        arg_estimate   {false};
+    std::string arg_label      {};
+    long        arg_max        {0};
+    long        arg_min        {0};
+    bool        arg_percentage {false};
+    bool        arg_remove     {false};
+    time_t      arg_start      {0};
+    int         arg_width      {80};
+    std::string arg_style      {};
 
     // Dynamically determine terminal width.
     unsigned short buff[4];
@@ -133,52 +121,36 @@ int main (int argc, char** argv)
       arg_width = buff[1];
 
     static struct option longopts[] = {
-      { "current",    required_argument, NULL, 'c' },
-#ifdef WAITING_FOR_VITAPI
-      { "done",       required_argument, NULL, 'd' },
-#endif
-      { "elapsed",    no_argument,       NULL, 'e' },
-      { "estimate",   no_argument,       NULL, 't' },
-      { "label",      required_argument, NULL, 'l' },
-      { "max",        required_argument, NULL, 'x' },
-      { "min",        required_argument, NULL, 'm' },
-      { "now",        no_argument,       NULL, 'n' },
-      { "percentage", no_argument,       NULL, 'p' },
-#ifdef WAITING_FOR_VITAPI
-      { "remaining",  required_argument, NULL, 'a' },
-#endif
-      { "remove",     no_argument,       NULL, 'r' },
-      { "start",      required_argument, NULL, 's' },
-      { "version",    no_argument,       NULL, 'v' },
-      { "width",      required_argument, NULL, 'w' },
-      { "style",      required_argument, NULL, 'y' },
-      { "help",       no_argument,       NULL, 'h' },
-      { NULL,         0,                 NULL, 0   }
+      { "current",    required_argument, nullptr, 'c' },
+      { "elapsed",    no_argument,       nullptr, 'e' },
+      { "estimate",   no_argument,       nullptr, 't' },
+      { "label",      required_argument, nullptr, 'l' },
+      { "max",        required_argument, nullptr, 'x' },
+      { "min",        required_argument, nullptr, 'm' },
+      { "now",        no_argument,       nullptr, 'n' },
+      { "percentage", no_argument,       nullptr, 'p' },
+      { "remove",     no_argument,       nullptr, 'r' },
+      { "start",      required_argument, nullptr, 's' },
+      { "version",    no_argument,       nullptr, 'v' },
+      { "width",      required_argument, nullptr, 'w' },
+      { "style",      required_argument, nullptr, 'y' },
+      { "help",       no_argument,       nullptr, 'h' },
+      { nullptr,      0,                 nullptr, 0   }
     };
 
     int ch;
-#ifdef WAITING_FOR_VITAPI
-    while ((ch = getopt_long (argc, argv, "c:d:etl:x:m:npa:rs:vw:h", longopts, NULL)) != -1)
-#else
-    while ((ch = getopt_long (argc, argv, "c:etl:x:m:nprs:vw:h", longopts, NULL)) != -1)
-#endif
+    while ((ch = getopt_long (argc, argv, "c:etl:x:m:nprs:vw:h", longopts, nullptr)) != -1)
     {
       switch (ch)
       {
       case 'c': arg_current    = atol (optarg);        break;
-#ifdef WAITING_FOR_VITAPI
-      case 'd': arg_done       = optarg;               break;
-#endif
       case 'e': arg_elapsed    = true;                 break;
       case 't': arg_estimate   = true;                 break;
       case 'l': arg_label      = optarg;               break;
       case 'x': arg_max        = atol (optarg);        break;
       case 'm': arg_min        = atol (optarg);        break;
-      case 'n': std::cout << time (NULL) << std::endl; exit (0);
+      case 'n': std::cout << time (nullptr) << std::endl; exit (0);
       case 'p': arg_percentage = true;                 break;
-#ifdef WAITING_FOR_VITAPI
-      case 'a': arg_remaining  = optarg;               break;
-#endif
       case 'r': arg_remove     = true;                 break;
       case 's': arg_start      = atoi (optarg);        break;
       case 'v': showVersion ();                        break;
@@ -205,7 +177,7 @@ int main (int argc, char** argv)
         throw std::string ("The --current value must not lie outside the --min/--max range.");
 
     if (arg_width && arg_label.length ())
-      if (arg_label.length () >= arg_width)
+      if (arg_label.length () >= static_cast <unsigned int> (arg_width))
         throw std::string ("The --label string is longer than the allowed --width value.");
 
     if (! arg_remove && ! (arg_min || arg_current || arg_max))
@@ -219,15 +191,21 @@ int main (int argc, char** argv)
 
     // Disallow signals from stopping the program while it is displaying color codes
     // Set up and render Progress object.
-    Progress p (arg_label, arg_width, arg_min, arg_max, arg_percentage, arg_remove);
-    p.setStyle (arg_style);
-    p.setStart (arg_start);
-    p.showElapsed (arg_elapsed);
-    p.showEstimate (arg_estimate);
-    p.removeAfter (arg_remove);
+    Progress p;
+    p.style      = arg_style;
+    p.label      = arg_label;
+    p.width      = arg_width;
+    p.minimum    = arg_min;
+    p.maximum    = arg_max;
+    p.percentage = arg_percentage;
+    p.remove     = arg_remove;
+    p.start      = arg_start;
+    p.elapsed    = arg_elapsed;
+    p.estimate   = arg_estimate;
+    p.remove     = arg_remove;
     p.update (arg_current);
 
-    if (arg_remove)
+    if (p.remove)
       p.done ();
   }
 
